@@ -1,6 +1,6 @@
-# $Id: autogen.sh,v 1.16 2007/10/03 12:47:19 rousseau Exp $
+# $Id: autogen.sh,v 1.17 2008/06/01 16:30:23 rikster5 Exp $
 
-# Exit is a command fails
+# Exit if a command fails
 set -e
 
 # Echo commands before they execute to help show progress
@@ -9,13 +9,6 @@ set -x
 # Clear files that will be rebuilt by autoconf, automake, & autoheader
 rm -f configure Makefile Makefile.in config.h.in
 
-# Create aclocal.m4, macros that are used in all subsequent processing
-aclocal -I m4
-
-# Prepare build for gettext.  Must precede intltoolize
-#gettextize only needs to be run when first adapting a program for NLS
-#gettextize --force --copy
-
 # autopoint is a lightweight gettextize which copies required files
 # but does not change Makefile.am
 autopoint --force
