@@ -1,4 +1,4 @@
-/* $Id: cp1250.c,v 1.9 2004/11/29 06:24:46 rikster5 Exp $ */
+/* $Id: cp1250.c,v 1.12 2010-10-15 23:50:06 rikster5 Exp $ */
 
 /*******************************************************************************
  * cp1250.c
@@ -22,21 +22,22 @@
 
 /*
  * Czech, Polish (and other CP 1250 languages) library
- * Convert Palm  <-> Unix:
+ * Convert charsets: Palm <-> Unix:
  * Palm : CP 1250
  * Unix : ISO-8859-2
  */
 
+/********************************* Includes ***********************************/
 #include "config.h"
 #include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include "cp1250.h"
-#include "log.h"
 
-/********** Unix: ISO **************************************************/
+/********************************* Constants **********************************/
+#define isCZ(c) ((c) & 0x80)
 
-const unsigned char w2l[128] = {
+/***** Unix: ISO *****/
+
+static const unsigned char w2l[128] = {
    0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0xa9, 0x8b,
    0xa6, 0xab, 0xae, 0xac, 0x90, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97,
    0x98, 0x99, 0xb9, 0x9b, 0xb6, 0xbb, 0xbe, 0xbc, 0xa0, 0xb7, 0xa2, 0xa3,
@@ -50,7 +51,7 @@ const unsigned char w2l[128] = {
    0xf8, 0xf9, 0xfa, 0xfb, 0xfc, 0xfd, 0xfe, 0xff
 };
 
-const unsigned char l2w[128] = {
+static const unsigned char l2w[128] = {
    0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0xa9, 0x8b,
    0xa6, 0xab, 0xae, 0xac, 0x90, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97,
    0x98, 0x99, 0xb1, 0x9b, 0xb6, 0xbb, 0xb5, 0xb7, 0xa0, 0xa5, 0xa2, 0xa3,
@@ -64,8 +65,7 @@ const unsigned char l2w[128] = {
    0xf8, 0xf9, 0xfa, 0xfb, 0xfc, 0xfd, 0xfe, 0xff
 };
 
-#define isCZ(c) ((c) & 0x80)
-
+/****************************** Main Code *************************************/
 void Win2Lat(char *const buf, int buf_len)
 {
    unsigned char *p;
@@ -75,7 +75,7 @@ void Win2Lat(char *const buf, int buf_len)
 
    for (i=0, p = (unsigned char *)buf; *p && i < buf_len; p++, i++) {
       if (isCZ(*p)) {
-	 *p = w2l[(*p) & 0x7f];
+         *p = w2l[(*p) & 0x7f];
       }
    }
 }
@@ -89,7 +89,7 @@ void Lat2Win(char *const buf, int buf_len)
 
    for (i=0, p = (unsigned char *)buf; *p && i < buf_len; p++, i++) {
       if (isCZ(*p)) {
-	 *p = l2w[(*p) & 0x7f];
+         *p = l2w[(*p) & 0x7f];
       }
    }
 }
