@@ -1,4 +1,4 @@
-/* $Id: datebook.c,v 1.67 2010-04-02 04:55:17 rikster5 Exp $ */
+/* $Id: datebook.c,v 1.73 2011-02-09 21:18:38 rousseau Exp $ */
 
 /*******************************************************************************
  * datebook.c
@@ -45,11 +45,12 @@
 #include "password.h"
 
 /****************************** Main Code *************************************/
-int appointment_on_day_list(int mon, int year, int *mask, int datebook_version)
+int appointment_on_day_list(int mon, int year, int *mask, 
+                            int category, int datebook_version)
 {
    struct tm tm_dom;
    CalendarEventList *tcel, *cel;
-   int dow, ndim, num;
+   int dow, ndim;
    int bit;
    int show_priv;
    int skip_privates;
@@ -64,7 +65,12 @@ int appointment_on_day_list(int mon, int year, int *mask, int datebook_version)
    /* Get private records back
     * We want to highlight a day with a private record if we are showing or
     * masking private records */
-   num = get_days_calendar_events2(&cel, NULL, 2, 2, 1, CATEGORY_ALL, NULL);
+   if (datebook_version) {
+      /* Calendar supports category option */
+      get_days_calendar_events2(&cel, NULL, 2, 2, 1, category, NULL);
+   } else {
+      get_days_calendar_events2(&cel, NULL, 2, 2, 1, CATEGORY_ALL, NULL);
+   }
 
    show_priv = show_privates(GET_PRIVATES);
    skip_privates = (show_priv==HIDE_PRIVATES);
@@ -79,10 +85,9 @@ int appointment_on_day_list(int mon, int year, int *mask, int datebook_version)
       if (*mask & bit) {
          continue;
       }
+      
       mktime(&tm_dom);
-
       for (tcel=cel; tcel; tcel = tcel->next) {
-         if (skip_privates && (tcel->mcale.attrib & dlpRecAttrSecret)) continue;
          if (calendar_isApptOnDate(&(tcel->mcale.cale), &tm_dom)) {
             *mask = *mask | bit;
             break;
@@ -141,11 +146,15 @@ int datebook_add_exception(struct CalendarEvent *cale, int year, int mon, int da
    return EXIT_SUCCESS;
 }
 
+
+/* All datebook appts are handled as calendar events now.
+ * This code scrap is being kept for reference only. */
+#if 0
 /*
  * If a copy is made, then it should be freed through free_Appointment
  */
-int datebook_copy_appointment(struct Appointment *a1,
-                              struct Appointment **a2)
+static int datebook_copy_appointment(struct Appointment *a1,
+                                     struct Appointment **a2)
 {
    long datebook_version;
 
@@ -174,6 +183,7 @@ int datebook_copy_appointment(struct Appointment *a1,
 
    return EXIT_SUCCESS;
 }
+#endif
 
 /*
  * If a copy is made, then it should be freed through free_CalendarEvent
@@ -184,6 +194,11 @@ int copy_calendar_event(const struct CalendarEvent *source,
    int r;
 
    *dest = malloc(sizeof(struct CalendarEvent));
+   if (*dest) {
+      /* zero out memory to remove valgrind warnings */
+      memset(*dest, 0, sizeof(struct CalendarEvent));
+   }
+  
    r = copy_CalendarEvent(source, *dest);
 
    if (!r) {
@@ -192,8 +207,11 @@ int copy_calendar_event(const struct CalendarEvent *source,
    return EXIT_FAILURE;
 }
 
-int datebook_sort(AppointmentList **al,
-                  int (*compare_func)(const void*, const void*))
+/* calendar_sort in calendar.c is now used for all datebook sorting
+ * This code scrap is being kept for reference only. */
+#if 0
+static int datebook_sort(AppointmentList **al,
+                         int (*compare_func)(const void*, const void*))
 {
    AppointmentList *temp_al;
    AppointmentList **sort_al;
@@ -234,6 +252,7 @@ int datebook_sort(AppointmentList **al,
 
    return EXIT_SUCCESS;
 }
+#endif
 
 #ifdef ENABLE_DATEBK
 static void db3_fill_struct(char *note, int type, struct db4_struct *db4)
@@ -288,6 +307,9 @@ static void db3_fill_struct(char *note, int type, struct db4_struct *db4)
    /* Byte 19 is a carriage return */
 }
 
+// FIXME: verify that new routine calendar_db3_hack_date in calendar.c
+// works for datebook databases as well and then remove.
+#if 0
 static int db3_hack_date(struct Appointment *appt, struct tm *today)
 {
    int t1, t2;
@@ -336,6 +358,7 @@ static int db3_hack_date(struct Appointment *appt, struct tm *today)
    }
    return EXIT_SUCCESS;
 }
+#endif
 
 /*
  * Parses the note tag and looks for db3 or db4 tags.
@@ -350,24 +373,24 @@ int db3_parse_tag(char *note, int *type, struct db4_struct *db4)
    /* NULL means any character is allowed */
    char *allowed[]={
       "#", "#", /* First 2 characters are # */
-        "@FfCcd", /* F or f floating, C or c completed, d done */
-        "@blL", /* b bold, l large, L large bold */
-        "@ABCDEFGHIJKLMNO", /* Category */
-        "@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_abcdefghijklmnopqrst", /* icon */
-        "@s", /* Spans midnight */
-        NULL, /* Lower 2 digits of next 2 chars are time zone */
-        NULL,
-        "@l\n", /* l link, EOL for datebk3 tags */
-        NULL, /* Lower 6 bits of next 4 chars make a 24 bit number (advance) */
-        NULL, /* I don't understand this yet and have not coded it */
-        NULL,
-        NULL,
-        NULL, /* Lower 6 bits of next 4 chars make a 24 bit number */
-        NULL, /*  which is the custom sound */
-        NULL,
-        NULL,
-        "@ABCDEFGHIJKLMNO", /* Color */
-        "\n", /* EOL for datebk4 tags */
+      "@FfCcd", /* F or f floating, C or c completed, d done */
+      "@blL", /* b bold, l large, L large bold */
+      "@ABCDEFGHIJKLMNO", /* Category */
+      "@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_abcdefghijklmnopqrst", /* icon */
+      "@s", /* Spans midnight */
+      NULL, /* Lower 2 digits of next 2 chars are time zone */
+      NULL,
+      "@l\n", /* l link, EOL for datebk3 tags */
+      NULL, /* Lower 6 bits of next 4 chars make a 24 bit number (advance) */
+      NULL, /* I don't understand this yet and have not coded it */
+      NULL,
+      NULL,
+      NULL, /* Lower 6 bits of next 4 chars make a 24 bit number */
+      NULL, /*  which is the custom sound */
+      NULL,
+      NULL,
+      "@ABCDEFGHIJKLMNO", /* Color */
+      "\n", /* EOL for datebk4 tags */
    };
    int len, i;
 
@@ -680,7 +703,7 @@ unsigned int calendar_isApptOnDate(struct CalendarEvent *cale, struct tm *date)
       break;
     default:
       jp_logf(JP_LOG_WARN, _("Unknown repeatType (%d) found in DatebookDB\n"),
-           cale->repeatType);
+                                                  cale->repeatType);
       ret = FALSE;
    }/* switch */
 
