@@ -1,4 +1,4 @@
-/* $Id: datebook.h,v 1.25 2010-02-28 18:53:02 judd Exp $ */
+/* $Id: datebook.h,v 1.30 2010-10-15 16:42:13 rikster5 Exp $ */
 
 /*******************************************************************************
  * datebook.h
@@ -75,11 +75,6 @@ struct db4_struct {
 int datebook_print(int type);
 int datebook_import(GtkWidget *window);
 int datebook_cleanup(void);
-int pc_datebook_write(struct Appointment *a, PCRecType rt,
-		      unsigned char attrib, unsigned int *unique_id);
-int pc_calendar_or_datebook_write(struct CalendarEvent *ce, PCRecType rt,
-				  unsigned char attrib, unsigned int *unique_id,
-				  long datebook_version);
 void free_AppointmentList(AppointmentList **al);
 
 /*
@@ -88,7 +83,7 @@ void free_AppointmentList(AppointmentList **al);
  * returns number of records in list.
  */
 int get_days_appointments(AppointmentList **al_out, struct tm *date,
-			  int *total_records);
+                          int *total_records);
 /*
  * If Null is passed in for date, then all appointments will be returned
  * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs.
@@ -96,43 +91,38 @@ int get_days_appointments(AppointmentList **al_out, struct tm *date,
  * returns number of records in list.
  */
 int get_days_appointments2(AppointmentList **appointment_list, struct tm *now,
-			   int modified, int deleted, int privates,
-			   int *total_records);
+                           int modified, int deleted, int privates,
+                           int *total_records);
 
 /* This function removes appointments from the list that obviously will not
  * occur in this month.  Skip privates will ignore private records.
  */
 int weed_datebook_list(AppointmentList **al, int mon, int year,
-		       int skip_privates, int *mask);
+                       int skip_privates, int *mask);
 
 int weed_calendar_event_list(CalendarEventList **cel, int mon, int year,
-			     int skip_privates, int *mask);
-
-/* Sorts a list of appointments according to the comparison function given */
-int datebook_sort(AppointmentList **al, 
-                  int (*compare_func)(const void*, const void*));
+                             int skip_privates, int *mask);
 
 /* Year is years since 1900 */
 /* Mon is 0-11 */
 /* Day is 1-31 */
 /* */
-int datebook_add_exception(struct CalendarEvent *ce, int year, int mon, int day);
+int datebook_add_exception(struct CalendarEvent *cale, int year, int mon, int day);
 int get_calendar_or_datebook_app_info(struct CalendarAppInfo *cai, long datebook_version);
 
-int datebook_copy_appointment(struct Appointment *a1,
-			     struct Appointment **a2);
 int copy_calendar_event(const struct CalendarEvent *source,
-			struct CalendarEvent **dest);
-/* returns a bit mask where bit 1 day one, etc. and it is set if an */
+                        struct CalendarEvent **dest);
+/* returns a bit mask where bit 1 is day one, etc.  Bit is set if an */
 /* appointment occurs on that day, 0 if not. */
-int appointment_on_day_list(int mon, int year, int *mask, int datebook_version);
+int appointment_on_day_list(int mon, int year, int *mask, 
+                            int category, int datebook_version);
 
 /*
  * returns 1 if an appointment does occur/re-occur on dat
  * else returns 0
  */
 unsigned int isApptOnDate(struct Appointment *a, struct tm *date);
-unsigned int calendar_isApptOnDate(struct CalendarEvent *ce, struct tm *date);
+unsigned int calendar_isApptOnDate(struct CalendarEvent *cale, struct tm *date);
 
 int compareTimesToDay(struct tm *tm1, struct tm *tm2);
 
@@ -149,7 +139,6 @@ int db3_has_tags(struct Appointment *a);
 int db3_which_icon(struct  Appointment *a);
 #endif
 
-int datebook_import(GtkWidget *window);
 int datebook_export(GtkWidget *window);
 
 #endif
