@@ -1,4 +1,7 @@
-/* i18n.h
+/* $Id: i18n.h,v 1.12 2010-03-29 05:44:29 rikster5 Exp $ */
+
+/*******************************************************************************
+ * i18n.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,28 +18,23 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #ifndef __I18N_H__
-#define __I18N_H__
+#  define __I18N_H__
 
-#include "config.h"
+#  include "config.h"
 
-#if defined(ENABLE_NLS)
-#if defined(HAVE_GETTEXT)
-#include	<libintl.h>
-#else
-#include	"intl/libintl.h"
-#endif
-#define	_(str)	gettext(str)
-#else
-#define	_(str)	str
-#endif
-
-#ifndef gettext_noop
-#define	gettext_noop(str) str
-#endif
-#ifndef N_
-#define N_(str) str
-#endif
+#  if defined(ENABLE_NLS)
+#    include <locale.h>
+#    include "gettext.h"
+#    define _(str) gettext(str)
+#    define N_(str) str
+#    define C_(context, str) pgettext(context, str)
+#  else
+#    define _(str) str
+#    define N_(str) str
+#    define C_(context, str) str
+#  endif
 
 #endif
