@@ -1,4 +1,4 @@
-/* $Id: install_user.c,v 1.12 2010-03-04 17:39:32 rousseau Exp $ */
+/* $Id: install_user.c,v 1.15 2010-10-18 04:55:45 rikster5 Exp $ */
 
 /*******************************************************************************
  * install_user.c
@@ -50,9 +50,14 @@ static char *jp_user_or_whoami(void)
    struct passwd *pw_ent;
    uid_t uid;
    const char *svalue;
+   long char_set;
 
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
    get_pref(PREF_USER, NULL, &svalue);
-   if ((svalue) && strlen(svalue)) return strdup(svalue);
+   if ((svalue) && (svalue[0])) {
+      /* Convert User Name stored in Palm character set */
+      return charset_p2newj(svalue, -1, char_set);
+   }
 
    uid = geteuid();
    pw_ent = getpwuid(uid);
@@ -72,11 +77,11 @@ static void cb_install_user_button(GtkWidget *widget, gpointer data)
    if (Pdata) {
       Pdata->button_hit = GPOINTER_TO_INT(data);
       if (Pdata->button_hit == DIALOG_SAID_1) {
-	 g_strlcpy(Pdata->user,
-	       gtk_entry_get_text(GTK_ENTRY(Pdata->user_entry)),
-	       sizeof(Pdata->user));
-	 sscanf(gtk_entry_get_text(GTK_ENTRY(Pdata->ID_entry)), "%lu",
-		&(Pdata->id));
+         g_strlcpy(Pdata->user,
+               gtk_entry_get_text(GTK_ENTRY(Pdata->user_entry)),
+               sizeof(Pdata->user));
+         sscanf(gtk_entry_get_text(GTK_ENTRY(Pdata->ID_entry)), "%lu",
+                &(Pdata->id));
       }
    }
 
@@ -91,8 +96,8 @@ static gboolean cb_destroy_dialog(GtkWidget *widget)
 }
 
 static int dialog_install_user(GtkWindow *main_window, 
-                        char *user, int user_len, 
-                        unsigned long *user_id)
+                               char *user, int user_len, 
+                               unsigned long *user_id)
 {
    GtkWidget *button, *label;
    GtkWidget *user_entry, *ID_entry;
@@ -108,20 +113,20 @@ static int dialog_install_user(GtkWindow *main_window,
    data.button_hit=0;
 
    install_user_dialog = gtk_widget_new(GTK_TYPE_WINDOW,
-					"type", GTK_WINDOW_TOPLEVEL,
-					"window_position", GTK_WIN_POS_MOUSE,
-					"title", _("Install User"),
-					NULL);
+                                        "type", GTK_WINDOW_TOPLEVEL,
+                                        "window_position", GTK_WIN_POS_MOUSE,
+                                        "title", _("Install User"),
+                                        NULL);
    gtk_window_set_modal(GTK_WINDOW(install_user_dialog), TRUE);
    if (main_window) {
       gtk_window_set_transient_for(GTK_WINDOW(install_user_dialog), GTK_WINDOW(main_window));
    }
 
    gtk_signal_connect(GTK_OBJECT(install_user_dialog), "destroy",
-		      GTK_SIGNAL_FUNC(cb_destroy_dialog), install_user_dialog);
+                      GTK_SIGNAL_FUNC(cb_destroy_dialog), install_user_dialog);
 
    gtk_object_set_data(GTK_OBJECT(install_user_dialog),
-		       "install_dialog_data", &data);
+                       "install_dialog_data", &data);
 
    vbox = gtk_vbox_new(FALSE, 5);
 
@@ -208,14 +213,14 @@ static int dialog_install_user(GtkWindow *main_window,
 
    button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_install_user_button),
-		      GINT_TO_POINTER(DIALOG_SAID_2));
+                      GTK_SIGNAL_FUNC(cb_install_user_button),
+                      GINT_TO_POINTER(DIALOG_SAID_2));
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 1);
 
    button = gtk_button_new_with_label(_("Install User"));
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_install_user_button),
-		      GINT_TO_POINTER(DIALOG_SAID_1));
+                      GTK_SIGNAL_FUNC(cb_install_user_button),
+                      GINT_TO_POINTER(DIALOG_SAID_1));
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 1);
    GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
    gtk_widget_grab_default(button);
@@ -231,24 +236,24 @@ static int dialog_install_user(GtkWindow *main_window,
    return data.button_hit;
 }
 
-void install_user_gui(GtkWidget *main_window)
+int install_user_gui(GtkWidget *main_window)
 {
    int r;
    char user[MAX_PREF_LEN];
    unsigned long user_id;
    const char *svalue;
-   long ivalue;
+   long old_user_id;
    char *old_user;
 
    r = dialog_install_user(GTK_WINDOW(main_window), user, MAX_PREF_LEN, &user_id);
    if (r == DIALOG_SAID_1) {
       /* Temporarily set the user and user ID */
       get_pref(PREF_USER, NULL, &svalue);
-      get_pref(PREF_USER_ID, &ivalue, NULL);
+      get_pref(PREF_USER_ID, &old_user_id, NULL);
       if (svalue) {
-	 old_user = strdup(svalue);
+         old_user = strdup(svalue);
       } else {
-	 old_user = strdup("");
+         old_user = strdup("");
       }
 
       set_pref(PREF_USER, 0, user, FALSE);
@@ -256,13 +261,18 @@ void install_user_gui(GtkWidget *main_window)
 
       jp_logf(JP_LOG_DEBUG, "user is %s\n", user);
       jp_logf(JP_LOG_DEBUG, "user id is %ld\n", user_id);
-      setup_sync(SYNC_NO_PLUGINS | SYNC_INSTALL_USER);
+      
+      r = setup_sync(SYNC_NO_PLUGINS | SYNC_INSTALL_USER);
 
-      jp_logf(JP_LOG_DEBUG, "old user is %s\n", user);
-      jp_logf(JP_LOG_DEBUG, "old user id is %ld\n", ivalue);
+      jp_logf(JP_LOG_DEBUG, "old user is %s\n", old_user);
+      jp_logf(JP_LOG_DEBUG, "old user id is %ld\n", old_user_id);
       set_pref(PREF_USER, 0, old_user, FALSE);
-      set_pref(PREF_USER_ID, ivalue, NULL, TRUE);
+      set_pref(PREF_USER_ID, old_user_id, NULL, TRUE);
       free(old_user);
-   }
+      
+      return r;
+   } 
+
+   return -1;
 }
 
