@@ -1,3 +1,5 @@
+/* $Id: jp-pi-contact.h,v 1.9 2010-04-21 09:40:05 rousseau Exp $ */
+
 /*******************************************************************************
  * jp-pi-contact.h:  Translate Palm contact data formats
  * A module of J-Pilot http://jpilot.org
@@ -24,6 +26,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+#ifndef __JP_PI_CONTACT_H_
+#define __JP_PI_CONTACT_H_
+
 #include "config.h"
 #include <pi-contact.h>
 
@@ -51,3 +56,5 @@ extern int jp_Contact_add_picture
 }
 #endif
 
+#endif
+
