@@ -1,4 +1,4 @@
-/* $Id: libplugin.h,v 1.37 2011-02-09 20:36:45 rousseau Exp $ */
+/* $Id: libplugin.h,v 1.39 2011-04-06 12:43:45 rousseau Exp $ */
 
 /*******************************************************************************
  * libplugin.h
@@ -277,6 +277,8 @@ int jp_pc_write(const char *DB_name, buf_rec *br);
 
 const char *jp_strstr(const char *haystack, const char *needle, int case_sense);
 
+int pc_read_next_rec(FILE *in, buf_rec *br);
+
 int read_header(FILE *pc_in, PC3RecordHeader *header);
 
 int write_header(FILE *pc_out, PC3RecordHeader *header);
@@ -313,7 +315,7 @@ int jp_cal_dialog(GtkWindow *main_window,
 
 /* I explain these below */
 typedef struct {
-   char *name;
+   const char *name;
    int usertype;
    int filetype;
    long ivalue;
