@@ -1,4 +1,4 @@
-/* $Id: log.c,v 1.32 2010-03-04 03:18:07 judd Exp $ */
+/* $Id: log.c,v 1.35 2010-10-15 16:42:13 rikster5 Exp $ */
 
 /*******************************************************************************
  * log.c
@@ -57,6 +57,9 @@ int glob_log_gui_mask;
 extern void output_to_pane(const char *str);
 extern pid_t jpilot_master_pid;
 
+/****************************** Prototypes ************************************/
+static int jp_vlogf (int level, const char *format, va_list val);
+
 /****************************** Main Code *************************************/
 int jp_logf(int level, const char *format, ...)
 {
@@ -75,19 +78,19 @@ int jp_logf(int level, const char *format, ...)
    return rval;
 }
 
-int jp_vlogf (int level, const char *format, va_list val) {
-   char       		real_buf[WRITE_MAX_BUF+32];
-   char			*buf, *local_buf;
-   int			size;
-   int			len;
-   int			r;
-   static FILE		*fp=NULL;
-   static int		err_count=0;
-   char			cmd[16];
+static int jp_vlogf (int level, const char *format, va_list val) {
+   char                 real_buf[WRITE_MAX_BUF+32];
+   char                 *buf, *local_buf;
+   int                  size;
+   int                  len;
+   int                  r;
+   static FILE          *fp=NULL;
+   static int           err_count=0;
+   char                 cmd[16];
 
    if (!((level & glob_log_file_mask) ||
-	 (level & glob_log_stdout_mask) ||
-	 (level & glob_log_gui_mask))) {
+         (level & glob_log_stdout_mask) ||
+         (level & glob_log_gui_mask))) {
       return EXIT_SUCCESS;
    }
 
@@ -105,8 +108,8 @@ int jp_vlogf (int level, const char *format, va_list val) {
 
       fp = fopen(fullname, "w");
       if (!fp) {
-	 fprintf(stderr, _("Unable to open log file\n"));
-	 err_count++;
+         fprintf(stderr, _("Unable to open log file\n"));
+         err_count++;
       }
    }
 
@@ -139,25 +142,25 @@ int jp_vlogf (int level, const char *format, va_list val) {
 
    /* free the buffer is a conversion was used */
    if (local_buf != buf)
-       g_free(local_buf);
+      g_free(local_buf);
 
    if ((pipe_to_parent) && (level & glob_log_gui_mask)) {
       /* do not use a pipe for intra-process log
        * otherwise we may have a dead lock (jpilot freezes) */
       if (getpid() == jpilot_master_pid)
-	 output_to_pane(buf);
+         output_to_pane(buf);
       else {
-	 sprintf(cmd, "%d:", PIPE_PRINT);
-	 len = strlen(cmd);
-	 buf = buf-len;
-	 strncpy(buf, cmd, len);
-	 size += len;
-	 buf[size]='\0';
-	 buf[size+1]='\n';
-	 size += 2;
-	 r = write(pipe_to_parent, buf, size);
-	 if (r<0)
-	    fprintf(stderr, "write returned error %s %d\n", __FILE__, __LINE__);
+         sprintf(cmd, "%d:", PIPE_PRINT);
+         len = strlen(cmd);
+         buf = buf-len;
+         strncpy(buf, cmd, len);
+         size += len;
+         buf[size]='\0';
+         buf[size+1]='\n';
+         size += 2;
+         r = write(pipe_to_parent, buf, size);
+         if (r<0)
+            fprintf(stderr, "write returned error %s %d\n", __FILE__, __LINE__);
       }
    }
 
@@ -173,7 +176,7 @@ int write_to_parent(int command, const char *format, ...)
    va_list val;
    int len, size;
    char real_buf[WRITE_MAX_BUF+32];
-   char	*buf;
+   char *buf;
    char cmd[20];
 
    buf=&(real_buf[16]);
@@ -190,7 +193,7 @@ int write_to_parent(int command, const char *format, ...)
    /* This is for jpilot-sync */
    if (pipe_to_parent==STDOUT_FILENO) {
       if (command==PIPE_PRINT) {
-	 write(pipe_to_parent, buf, strlen(buf));
+         write(pipe_to_parent, buf, strlen(buf));
       }
       return TRUE;
    }
