@@ -1,4 +1,4 @@
-/* $Id: monthview_gui.c,v 1.55 2010-04-20 18:13:26 rikster5 Exp $ */
+/* $Id: monthview_gui.c,v 1.58 2010-11-10 03:57:47 rikster5 Exp $ */
 
 /*******************************************************************************
  * monthview_gui.c
@@ -54,8 +54,8 @@ static int glob_offset;
 static struct tm glob_month_date;
 
 /****************************** Prototypes ************************************/
-int display_months_appts(struct tm *glob_month_date, GtkWidget **glob_month_texts);
-void hide_show_month_boxes(void);
+static int display_months_appts(struct tm *glob_month_date, GtkWidget **glob_month_texts);
+static void hide_show_month_boxes(void);
 
 /****************************** Main Code *************************************/
 static gboolean cb_destroy(GtkWidget *widget)
@@ -156,7 +156,7 @@ static void cb_enter_selected_day(GtkWidget *widget,
  * Also, set a global offset for indexing day 1.
  * Also relabel day labels.
  */
-void hide_show_month_boxes(void)
+static void hide_show_month_boxes(void)
 {
    int n;
    int dow, ndim;
@@ -281,7 +281,7 @@ static void create_month_boxes_texts(GtkWidget *month_vbox)
    gtk_box_pack_start(GTK_BOX(month_vbox), text, TRUE, TRUE, 4);
 }
 
-int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
+static int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
 {
    CalendarEventList *ce_list;
    CalendarEventList *temp_cel;
@@ -418,14 +418,13 @@ void monthview_gui(struct tm *date_in)
    char str_dow[256];
    long fdow;
    char title[200];
-   long w, h;
+   long w, h, show_tooltips;
 
    if (monthview_window) {
        /* Delete any existing window to ensure that new window is biased
         * around currently selected date and so that the new window
-        * contents are updated with any changes on the day view.
-        */
-       gtk_widget_destroy(monthview_window);
+        * contents are updated with any changes on the day view. */
+      gtk_widget_destroy(monthview_window);
    }
 
    memcpy(&glob_month_date, date_in, sizeof(struct tm));
@@ -434,6 +433,7 @@ void monthview_gui(struct tm *date_in)
 
    get_pref(PREF_MONTHVIEW_WIDTH, &w, NULL);
    get_pref(PREF_MONTHVIEW_HEIGHT, &h, NULL);
+   get_pref(PREF_SHOW_TOOLTIPS, &show_tooltips, NULL);
 
    g_snprintf(title, sizeof(title), "%s %s", PN, _("Monthly View"));
 
@@ -476,8 +476,8 @@ void monthview_gui(struct tm *date_in)
    /* Accelerator key for left arrow */
    gtk_widget_add_accelerator(GTK_WIDGET(button), "clicked", accel_group, 
                               GDK_Left, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
-   gtk_tooltips_set_tip(glob_tooltips, button,
-                        _("Last month   Alt+LeftArrow"), NULL);
+   set_tooltip(show_tooltips, glob_tooltips, 
+               button, _("Last month   Alt+LeftArrow"), NULL);
 
    /* Close button */
    button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
@@ -504,8 +504,8 @@ void monthview_gui(struct tm *date_in)
    /* Accelerator key for right arrow */
    gtk_widget_add_accelerator(GTK_WIDGET(button), "clicked", accel_group, 
                               GDK_Right, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
-   gtk_tooltips_set_tip(glob_tooltips, button,
-                        _("Next month   Alt+RightArrow"), NULL);
+   set_tooltip(show_tooltips, glob_tooltips,
+               button, _("Next month   Alt+RightArrow"), NULL);
 
    /* Month name label */
    jp_strftime(str, sizeof(str), "%B %Y", &glob_month_date);
