@@ -1,4 +1,4 @@
-/* $Id: print.c,v 1.53 2010-10-19 00:33:39 rikster5 Exp $ */
+/* $Id: print.c,v 1.55 2011-04-06 11:58:47 rousseau Exp $ */
 
 /*******************************************************************************
  * print.c
@@ -57,7 +57,7 @@ static FILE *out;
 static int first_hour, first_min, last_hour, last_min;
 extern int datebk_category;
 
-static char *PaperSizes[] = { 
+static const char *PaperSizes[] = { 
    "Letter", "Legal", "Statement", "Tabloid", "Ledger", "Folio", "Quarto",
    "7x9", "9x11", "9x12", "10x13", "10x14", "Executive", 
    "A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", "A8", "A9", "A10",
@@ -69,7 +69,7 @@ static char *PaperSizes[] = {
 
 /****************************** Prototypes ************************************/
 static int fill_in(struct tm *date, CalendarEventList *a_list);
-static void ps_strncat(char *dest, char *src, int n);
+static void ps_strncat(char *dest, const char *src, int n);
 
 /****************************** Main Code *************************************/
 static FILE *print_open(void)
@@ -110,7 +110,7 @@ static int clip_to_box(float x1, float y1, float x2, float y2)
    return EXIT_SUCCESS;
 }
 
-static int puttext(float x, float y, char *text)
+static int puttext(float x, float y, const char *text)
 {
    int len;
    char *buf;
@@ -361,7 +361,7 @@ static int f_indent_print(FILE *f, int indent, char *str) {
  * ps_strncat   Escapes brackets for printing in PostScript strings
  *----------------------------------------------------------------------*/
 
-void ps_strncat(char *dest, char *src, int n)
+void ps_strncat(char *dest, const char *src, int n)
 {
    int i = 0, j = 0;
    char *dest2;
@@ -402,7 +402,7 @@ static int days_in_mon(struct tm *date)
  *                      appointments.
  *----------------------------------------------------------------------*/
 
-static char *MonthNames[] = {
+static const char *MonthNames[] = {
    "January", "February", "March", "April", "May", "June", "July",
    "August", "September", "October", "November", "December"
 };
