@@ -1,14 +1,38 @@
+/* $Id: russian.c,v 1.9 2010-10-15 23:50:07 rikster5 Exp $ */
+
+/*******************************************************************************
+ * russian.c
+ * A module of J-Pilot http://jpilot.org
+ *
+ * Copyright (C) 2000 by Gennady Kudelya
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ ******************************************************************************/
+
 /*
-	Convert Palm  <-> Unix:
-		Palm : koi8
-		Unix : Win1251
+        Convert charsets: Palm <-> Unix
+                          Palm  :  koi8
+                          Unix  :  Win1251
 */
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include <stdio.h>
+#include <stdlib.h>
 #include "russian.h"
 
-const unsigned char k2w[256] = {
+/********************************* Constants **********************************/
+static const unsigned char k2w[256] = {
    0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,
    0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f,
    0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17,
@@ -43,7 +67,7 @@ const unsigned char k2w[256] = {
    0xdb,0xdd,0xdf,0xd9,0xd8,0xdc,0xc0,0xd1
 };
 
-const unsigned char w2k[256] = {
+static const unsigned char w2k[256] = {
    0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,
    0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f,
    0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17,
@@ -78,27 +102,28 @@ const unsigned char w2k[256] = {
    0xdc,0xdb,0xc7,0xd8,0xdd,0xd9,0xd7,0xda
 };
 
-void win1251_to_koi8(unsigned char *const buf, int buf_len)
+/****************************** Main Code *************************************/
+void win1251_to_koi8(char *const buf, int buf_len)
 {
    unsigned char *p;
    int i;
 
    if (buf == NULL) return;
 
-   for (i=0, p = buf; *p && i < buf_len; p++, i++) {
-      *p = w2k[(*p)]; 
+   for (i=0, p = (unsigned char *)buf; *p && i < buf_len; p++, i++) {
+      *p = w2k[(*p)];
    }
 }
 
-
-void koi8_to_win1251(unsigned char *const buf, int buf_len)
+void koi8_to_win1251(char *const buf, int buf_len)
 {
    unsigned char *p;
    int i;
 
    if (buf == NULL) return;
 
-   for (i=0, p = buf; *p && i < buf_len; p++, i++) {
+   for (i=0, p = (unsigned char *)buf; *p && i < buf_len; p++, i++) {
         *p = k2w[(*p)];
    }
 }
+
