@@ -1,4 +1,4 @@
-/* $Id: weekview_gui.c,v 1.53 2010-04-20 18:13:26 rikster5 Exp $ */
+/* $Id: weekview_gui.c,v 1.56 2010-11-10 03:57:48 rikster5 Exp $ */
 
 /*******************************************************************************
  * weekview_gui.c
@@ -50,8 +50,8 @@ static GObject   *week_day_text_buffer[8];
 static struct tm glob_week_date;
 
 /****************************** Prototypes ************************************/
-int clear_weeks_appts(GtkWidget **day_texts);
-int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts);
+static int clear_weeks_appts(GtkWidget **day_texts);
+static int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts);
 
 /****************************** Main Code *************************************/
 static gboolean cb_destroy(GtkWidget *widget)
@@ -122,7 +122,7 @@ static void cb_week_move(GtkWidget *widget, gpointer data)
    thaw_weeks_appts();
 }
 
-int clear_weeks_appts(GtkWidget **day_texts)
+static int clear_weeks_appts(GtkWidget **day_texts)
 {
    int i;
    GObject   *text_buffer;
@@ -140,7 +140,7 @@ int clear_weeks_appts(GtkWidget **day_texts)
  * It will then print the next eight days to the day_texts array of
  * text boxes.
  */
-int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
+static int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 {
    CalendarEventList *ce_list;
    CalendarEventList *temp_cel;
@@ -279,19 +279,20 @@ void weekview_gui(struct tm *date_in)
    long fdow;
    int i;
    char title[200];
-   long w, h;
+   long w, h, show_tooltips;
 
    if (weekview_window) {
-       /* Delete any existing window to ensure that new window is biased
-        * around currently selected date and so that the new window
-        * contents are updated with any changes on the day view. */
-       gtk_widget_destroy(weekview_window);
+      /* Delete any existing window to ensure that new window is biased
+       * around currently selected date and so that the new window
+       * contents are updated with any changes on the day view. */
+      gtk_widget_destroy(weekview_window);
    }
 
    memcpy(&glob_week_date, date_in, sizeof(struct tm));
 
    get_pref(PREF_WEEKVIEW_WIDTH, &w, NULL);
    get_pref(PREF_WEEKVIEW_HEIGHT, &h, NULL);
+   get_pref(PREF_SHOW_TOOLTIPS, &show_tooltips, NULL);
 
    g_snprintf(title, sizeof(title), "%s %s", PN, _("Weekly View"));
    weekview_window = gtk_widget_new(GTK_TYPE_WINDOW,
@@ -332,8 +333,8 @@ void weekview_gui(struct tm *date_in)
    /* Accelerator key for left arrow */
    gtk_widget_add_accelerator(GTK_WIDGET(button), "clicked", accel_group, 
                               GDK_Left, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
-   gtk_tooltips_set_tip(glob_tooltips, button,
-                        _("Last week   Alt+LeftArrow"), NULL);
+   set_tooltip(show_tooltips, glob_tooltips, 
+               button, _("Last week   Alt+LeftArrow"), NULL);
 
    /* Close button */
    button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
@@ -361,8 +362,8 @@ void weekview_gui(struct tm *date_in)
    /* Accelerator key for right arrow */
    gtk_widget_add_accelerator(GTK_WIDGET(button), "clicked", accel_group, 
                               GDK_Right, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
-   gtk_tooltips_set_tip(glob_tooltips, button,
-                        _("Next week   Alt+RightArrow"), NULL);
+   set_tooltip(show_tooltips, glob_tooltips, 
+               button, _("Next week   Alt+RightArrow"), NULL);
 
    get_pref(PREF_FDOW, &fdow, NULL);
 
